## 1.0.7 (2024-12-11)

### added (1 change)

- [Add FLEX_NEXT decoding to multimon-ng.](lucid/mmng-ui@186e0c198a5ca266519ae0cf56a1cf85371c2291)

## 1.0.6 (2024-12-09)

### fixed (1 change)

- [FLEX fixes.](lucid/mmng-ui@77242a8ea0658def57cc63a1ddac84200379378c)

### added (1 change)

- [Add a filter feature.](lucid/mmng-ui@da2c8ee3f4a48ab0b0ece98693f7ec2b7132f391)

## 1.0.5 (2024-10-09)

### fixed (1 change)

- Bugfixes, doco and tidy up

## 1.0.4 (2024-10-08)

### fixed (1 change)

- Bugfix

## 1.0.3 (2024-10-07)

### added (1 change)

- [CLI argument for listening port](lucid/mmng-ui@246ceb3808d5e2cfb25d85f6a7ba70a3e4ec6d75)

## 1.0.2 (2024-10-06)

### fixed (1 change)

- [JSON support detection in multimon-ng](lucid/mmng-ui@a0f8318dfaa4e0f55d878beb0096a90947ffae75)

## 1.0.1 (2024-10-06)

### changed (1 change)

- Re-code reader.py a little

### added (1 change)

- More tests

### fixed (1 change)

- [Parse normal output or JSON mode](lucid/mmng-ui@d71897dc24e553f9a0a04dc3b4f59cbeb0296b7b)

## 1.0.0 (2024-10-04)

### other (1 change)

- Initial release
